/* $Id: output.h 309 2006-10-22 11:38:07Z steve $ */
#ifndef AWFFULL_OUTPUT_H
#define AWFFULL_OUTPUT_H

extern int write_main_index(void);              /* produce main HTML   */
extern int write_month_html(void);              /* monthy HTML page    */
extern FILE *open_out_file(char *);             /* open output file    */

/* define some colors for HTML */
#define WHITE          "#FFFFFF"
#define BLACK          "#000000"
#define RED            "#FF0000"
#define ORANGE         "#FF8000"
#define LTBLUE         "#0080FF"
#define BLUE           "#0000FF"
#define GREEN          "#00FF00"
#define DKGREEN        "#00805C"
#define GREY           "#C0C0C0"
#define LTGREY         "#E8E8E8"
#define YELLOW         "#FFFF00"
#define PURPLE         "#FF00FF"
#define CYAN           "#00E0FF"
#define GRPCOLOR       "#D0D0E0"
#define BROWN          "#FFC480"
#define LTGREEN        "#80FFC0"

#define MAX_404_RECORDS 1000


#endif          /* AWFFULL_OUTPUT_H */
